pub enum LineCollectionOptions {
Bounded {
max_bytes: NumBytes,
max_lines: usize,
overflow_behavior: CollectionOverflowBehavior,
},
TrustedUnbounded,
}Expand description
Options for collecting parsed output lines into memory.
Variants
Bounded
Retain at most max_bytes total line bytes and at most max_lines lines in memory.
Fields

overflow_behavior: CollectionOverflowBehaviorWhich retained lines to keep when more output is observed.
TrustedUnbounded
Retain all observed lines in memory without a total output cap.
Use only when the output source and its output volume are trusted.