pub enum LineOverflowBehavior {
DropAdditionalData,
EmitAdditionalAsNewLines,
}Expand description
What should happen when a line is too long?
Variants
DropAdditionalData
Drop any additional data received after the current line was considered too long until the next newline character is observed, which then starts a new line.
EmitAdditionalAsNewLines
Emit the current line when the maximum allowed length is reached. Any additional data received is immediately taken as the content of the next line.
This option really just adds intermediate line breaks to not let any emitted line exceed the length limit.
No data is dropped with this behavior.