pub enum RawCollectionOptions {
Bounded {
max_bytes: NumBytes,
overflow_behavior: CollectionOverflowBehavior,
},
TrustedUnbounded,
}Expand description
Options for collecting raw output bytes into memory.
Variants
Bounded
Retain at most max_bytes bytes in memory.
Fields

overflow_behavior: CollectionOverflowBehaviorWhich retained bytes to keep when more output is observed.
TrustedUnbounded
Retain all observed bytes in memory without a total output cap.
Use only when the output source and its output volume are trusted.