#[non_exhaustive]pub enum StreamConsumerError {
ActiveConsumer {
stream_name: &'static str,
},
}Expand description
Errors that can occur when creating a stream consumer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ActiveConsumer
A single-subscriber stream already has an active consumer.
Implementations
Sourceimpl StreamConsumerError
impl StreamConsumerError
Sourcepub fn stream_name(&self) -> &'static str
pub fn stream_name(&self) -> &'static str
The name of the stream that rejected the consumer.