pub enum WaitForCompletionOrTerminateResult<T = ExitStatus> {
Completed(T),
TerminatedAfterTimeout {
result: T,
timeout: Duration,
},
}Expand description
Result of waiting for a process to complete, terminating it if the wait times out.
Variants
Completed(T)
The process completed before the wait timeout elapsed.
TerminatedAfterTimeout
The wait timeout elapsed, then cleanup termination completed successfully.
Implementations
Sourceimpl<T> WaitForCompletionOrTerminateResult<T>
impl<T> WaitForCompletionOrTerminateResult<T>
Sourcepub fn into_result(self) -> T
pub fn into_result(self) -> T
Returns the terminal value, whether completion happened before timeout or after cleanup.
Sourcepub fn into_completed(self) -> Option<T>
pub fn into_completed(self) -> Option<T>
Returns the completed value, or None if cleanup termination was required after timeout.
Sourcepub fn expect_completed(self, message: &str) -> T
pub fn expect_completed(self, message: &str) -> T
Returns the completed value, panicking with message if cleanup termination was required.
Panics
Panics with message if this result is
WaitForCompletionOrTerminateResult::TerminatedAfterTimeout.