WaitForCompletionResult

Enum WaitForCompletionResult 

pub enum WaitForCompletionResult<T = ExitStatus> {
    Completed(T),
    Timeout {
        timeout: Duration,
    },
}
Result of waiting for a process to complete within an explicit timeout.

Variants



Completed(T)

The process completed before the timeout elapsed.



Timeout

The timeout elapsed before the process completed.

Fields

timeout: Duration

The timeout duration that was exceeded.

Implementations

Source

impl<T> WaitForCompletionResult<T>

pub fn into_completed(self) -> Option<T>

Returns the completed value, or None if the wait timed out.

pub fn expect_completed(self, message: &str) -> T

Returns the completed value, panicking with message if the wait timed out.

Panics

Panics with message if this result is WaitForCompletionResult::Timeout.