#[non_exhaustive]pub enum WaitOrTerminateError {
WaitFailed {
process_name: Cow<'static, str>,
wait_error: Box<WaitError>,
termination_status: ExitStatus,
},
TerminationFailed {
process_name: Cow<'static, str>,
wait_error: Box<WaitError>,
termination_error: TerminationError,
},
TerminationAfterTimeoutFailed {
process_name: Cow<'static, str>,
timeout: Duration,
termination_error: TerminationError,
},
}Expand description
Errors that can occur when waiting for a process with automatic termination on failure.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WaitFailed
Waiting failed, but the subsequent cleanup termination succeeded.
Fields

termination_status: ExitStatusThe status observed after cleanup termination.
TerminationFailed
Waiting failed, and the subsequent cleanup termination also failed.
Fields

termination_error: TerminationErrorThe error returned while trying to terminate the process after the wait failure.
TerminationAfterTimeoutFailed
Waiting timed out, and the subsequent cleanup termination failed.