CollectLineSinkAsync

Struct CollectLineSinkAsync 

pub struct CollectLineSinkAsync<T, C> { /* private fields */ }
AsyncLineSink holding the user collector and a sink. Compose with LineAdapter (its AsyncStreamVisitor impl is selected automatically when the inner sink is an AsyncLineSink) to drive collect_lines_async.

Implementations

Source

impl<T, C> CollectLineSinkAsync<T, C>
where T: Sink, C: AsyncLineCollector<T>,

pub fn new(sink: T, collector: C) -> Self

Creates a new sink that awaits collector with each parsed line and a &mut borrow of sink.