FromStreamOptions

Struct FromStreamOptions 

pub struct FromStreamOptions {
    pub chunk_size: NumBytes,
    pub channel_capacity: usize,
}
NOTE: The maximum possible memory consumption is: chunk_size * channel_capacity. Although reaching that level requires:

  1. A receiver to listen for chunks.
  2. The channel getting full.

Fields

chunk_size: NumBytes

The size of an individual chunk read from the read buffer in bytes.

Must be greater than zero.

default: 16 * 1024 // 16 kb

channel_capacity: usize

The number of chunks held by the underlying async channel.

When the subscriber (if present) is not fast enough to consume chunks equally fast or faster than them getting read, this acts as a buffer to hold not-yet processed messages. The bigger, the better, in terms of system resilience to write-spikes. Multiply with chunk_size to obtain the amount of system resources this will consume at max.