pub struct LineOutputOptions {
pub line_parsing_options: LineParsingOptions,
pub stdout_collection_options: LineCollectionOptions,
pub stderr_collection_options: LineCollectionOptions,
}Expand description
Options for line output collection from stdout and stderr.
Fields
line_parsing_options: LineParsingOptionsOptions used for parsing stdout and stderr chunks into lines.
stdout_collection_options: LineCollectionOptionsCollection options used for stdout.
stderr_collection_options: LineCollectionOptionsCollection options used for stderr.