Output

Struct Output 

pub struct Output {
    pub status: ExitStatus,
    pub stdout: Vec<String>,
    pub stderr: Vec<String>,
}
Full output of a process that terminated.

Both it’s stdout and stderr streams were collected as individual lines. Depending on the crate::LineParsingOptions used, content might have been lost.

Fields

status: ExitStatus

Status the process exited with.

stdout: Vec<String>

The processes entire output on its stdout stream, collected into individual lines.

Depending on the crate::LineParsingOptions used, content might have been lost.

stderr: Vec<String>

The processes entire output on its stderr stream, collected into individual lines.

Depending on the crate::LineParsingOptions used, content might have been lost.