pub struct RawOutput {
pub status: ExitStatus,
pub stdout: Vec<u8>,
pub stderr: Vec<u8>,
}Expand description
Full raw byte output of a process that terminated.
Both its stdout and stderr streams were collected as bytes without line parsing.
Fields
status: ExitStatusStatus the process exited with.
stdout: Vec<u8>The process’s entire output on its stdout stream, collected as raw bytes.
stderr: Vec<u8>The process’s entire output on its stderr stream, collected as raw bytes.