pub struct SinkWriteError { /* private fields */ }Expand description
Details about a failed async write into a collector sink.
Implementations
Sourceimpl SinkWriteError
impl SinkWriteError
Sourcepub fn stream_name(&self) -> &'static str
pub fn stream_name(&self) -> &'static str
The name of the stream this collector operates on.
Sourcepub fn operation(&self) -> SinkWriteOperation
pub fn operation(&self) -> SinkWriteOperation
The write operation that failed.
Sourcepub fn attempted_len(&self) -> usize
pub fn attempted_len(&self) -> usize
Number of bytes passed to the failed write_all call.