pub struct StreamReadError { /* private fields */ }Expand description
Error emitted when an output stream cannot be read to completion.
Implementations
Sourceimpl StreamReadError
impl StreamReadError
Sourcepub fn new(stream_name: &'static str, source: Error) -> Self
pub fn new(stream_name: &'static str, source: Error) -> Self
Creates a stream read error from the stream name and underlying IO error.
Sourcepub fn stream_name(&self) -> &'static str
pub fn stream_name(&self) -> &'static str
The name of the stream that failed.
Sourcepub fn kind(&self) -> ErrorKind
pub fn kind(&self) -> ErrorKind
The io::ErrorKind of the underlying read failure.
Sourcepub fn source_io_error(&self) -> &Error
pub fn source_io_error(&self) -> &Error
The underlying IO error.