#[non_exhaustive]pub struct TerminationAttemptError {
pub phase: TerminationAttemptPhase,
pub operation: TerminationAttemptOperation,
pub signal_name: Option<&'static str>,
pub source: Box<dyn Error + Send + Sync + 'static>,
}Expand description
A failed operation recorded while attempting to terminate a process.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.phase: TerminationAttemptPhaseTermination phase where the failure happened.
operation: TerminationAttemptOperationOperation that failed during the phase.
signal_name: Option<&'static str>Platform signal involved in the failed operation, when applicable.
source: Box<dyn Error + Send + Sync + 'static>Original source error.