UnixGracefulPhase

Struct UnixGracefulPhase 

pub struct UnixGracefulPhase {
    pub signal: UnixGracefulSignal,
    pub timeout: Duration,
}
One step of a Unix graceful-shutdown sequence: a signal to send and a maximum time to wait for the child to exit before escalating.

Fields

signal: UnixGracefulSignal

Signal sent at the start of this phase.

timeout: Duration

Maximum time to wait for the child to exit after signal is sent. When this elapses the sequence escalates to the next phase, or to the implicit SIGKILL fallback if this is the last phase.

Implementations

Source

impl UnixGracefulPhase

pub const fn interrupt(timeout: Duration) -> Self

Convenience constructor for a SIGINT phase.

pub const fn terminate(timeout: Duration) -> Self

Convenience constructor for a SIGTERM phase.