OutputStream

Trait OutputStream 

pub trait OutputStream: Consumable {
    // Required methods
    fn read_chunk_size(&self) -> NumBytes;
    fn max_buffered_chunks(&self) -> usize;
    fn name(&self) -> &'static str;
}
We support the following implementations:

Required Methods

fn read_chunk_size(&self) -> NumBytes

The maximum size of every chunk read by the backing stream_reader.

fn max_buffered_chunks(&self) -> usize

The number of chunks held by the underlying async channel.

fn name(&self) -> &'static str

Type of stream. Can be “stdout” or “stderr”. But we do not guarantee this output. It should only be used for logging/debugging.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors