SinkWriteErrorHandler

Trait SinkWriteErrorHandler 

pub trait SinkWriteErrorHandler: Send + 'static {
    // Required method
    fn handle(&mut self, error: &SinkWriteError) -> SinkWriteErrorAction;
}
Handles async writer sink failures observed by writer collectors.

Required Methods

fn handle(&mut self, error: &SinkWriteError) -> SinkWriteErrorAction

Decide whether collection should continue after a sink write failure.

Implementors