Struct BroadcastOutputStream

pub struct BroadcastOutputStream { /* private fields */ }
The output stream from a process. Either representing stdout or stderr.

This is the broadcast variant, allowing for multiple simultaneous consumers with the downside of inducing memory allocations not required when only one consumer is listening. For that case, prefer using the output_stream::single_subscriber::SingleOutputSteam.

Implementations

Source

impl BroadcastOutputStream

pub fn inspect_chunks( &self, f: impl FnMut(Chunk) -> Next + Send + 'static, ) -> Inspector

pub fn inspect_lines( &self, f: impl FnMut(String) -> Next + Send + 'static, options: LineParsingOptions, ) -> Inspector

pub fn inspect_lines_async<Fut>( &self, f: impl FnMut(String) -> Fut + Send + 'static, options: LineParsingOptions, ) -> Inspector
where Fut: Future<Output = Next> + Send,

Source

impl BroadcastOutputStream

pub fn collect_chunks<S: Sink>( &self, into: S, collect: impl FnMut(Chunk, &mut S) + Send + 'static, ) -> Collector<S>

pub fn collect_chunks_async<S, F>(&self, into: S, collect: F) -> Collector<S>
where S: Sink, F: Fn(Chunk, &mut S) -> Pin<Box<dyn Future<Output = Next> + Send + '_>> + Send + 'static,

pub fn collect_lines<S: Sink>( &self, into: S, collect: impl FnMut(String, &mut S) -> Next + Send + 'static, options: LineParsingOptions, ) -> Collector<S>

pub fn collect_lines_async<S, F>( &self, into: S, collect: F, options: LineParsingOptions, ) -> Collector<S>
where S: Sink, F: Fn(String, &mut S) -> Pin<Box<dyn Future<Output = Next> + Send + '_>> + Send + Sync + 'static,

pub fn collect_chunks_into_vec(&self) -> Collector<Vec<u8>>

pub fn collect_lines_into_vec( &self, options: LineParsingOptions, ) -> Collector<Vec<String>>

pub fn collect_chunks_into_write<W: Sink + AsyncWriteExt + Unpin>( &self, write: W, ) -> Collector<W>

pub fn collect_lines_into_write<W: Sink + AsyncWriteExt + Unpin>( &self, write: W, options: LineParsingOptions, ) -> Collector<W>

pub fn collect_chunks_into_write_mapped<W: Sink + AsyncWriteExt + Unpin, B: AsRef<[u8]> + Send>( &self, write: W, mapper: impl Fn(Chunk) -> B + Send + Sync + Copy + 'static, ) -> Collector<W>

pub fn collect_lines_into_write_mapped<W: Sink + AsyncWriteExt + Unpin, B: AsRef<[u8]> + Send>( &self, write: W, mapper: impl Fn(String) -> B + Send + Sync + Copy + 'static, options: LineParsingOptions, ) -> Collector<W>

Source

impl BroadcastOutputStream

pub async fn wait_for_line( &self, predicate: impl Fn(String) -> bool + Send + Sync + 'static, options: LineParsingOptions, )

pub async fn wait_for_line_with_timeout( &self, predicate: impl Fn(String) -> bool + Send + Sync + 'static, options: LineParsingOptions, timeout: Duration, ) -> Result<(), Elapsed>