pub enum DeliveryGuarantee {
BestEffort,
ReliableForActiveSubscribers,
}Expand description
Runtime delivery behavior used by typed stream modes.
Variants
BestEffort
Keep reading output and emit gaps or drop output for slow consumers when bounded buffers overflow.
ReliableForActiveSubscribers
Wait for active consumers before reading more output when bounded buffers are full.