#[non_exhaustive]pub enum TerminationError {
SignalFailed {
process_name: Cow<'static, str>,
attempt_errors: Vec<TerminationAttemptError>,
},
TerminationFailed {
process_name: Cow<'static, str>,
attempt_errors: Vec<TerminationAttemptError>,
},
}Expand description
Errors that can occur when terminating a process.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SignalFailed
Failed to manually send a graceful signal to the process.
Fields

attempt_errors: Vec<TerminationAttemptError>Errors recorded while attempting to send the signal, in chronological order.
TerminationFailed
Failed to terminate the process after trying all platform termination signals.
Implementations
Sourceimpl TerminationError
impl TerminationError
Sourcepub fn process_name(&self) -> &str
pub fn process_name(&self) -> &str
The name of the process involved in the termination error.
Sourcepub fn attempt_errors(&self) -> &[TerminationAttemptError]
pub fn attempt_errors(&self) -> &[TerminationAttemptError]
Errors recorded while attempting the operation, in chronological order.