pub enum WaitForCompletionResult<T = ExitStatus> {
Completed(T),
Timeout {
timeout: Duration,
},
}Expand description
Result of waiting for a process to complete within an explicit timeout.
Variants
Completed(T)
The process completed before the timeout elapsed.
Timeout
The timeout elapsed before the process completed.
Implementations
Sourceimpl<T> WaitForCompletionResult<T>
impl<T> WaitForCompletionResult<T>
Sourcepub fn into_completed(self) -> Option<T>
pub fn into_completed(self) -> Option<T>
Returns the completed value, or None if the wait timed out.
Sourcepub fn expect_completed(self, message: &str) -> T
pub fn expect_completed(self, message: &str) -> T
Returns the completed value, panicking with message if the wait timed out.
Panics
Panics with message if this result is WaitForCompletionResult::Timeout.