pub enum WaitForLineResult {
Matched,
StreamClosed,
Timeout,
}Expand description
Result of waiting for an output line matching a predicate.
Note that not every function returning this enum can produce every variant:
crate::output_stream::broadcast::BroadcastOutputStream::wait_for_line and
crate::output_stream::single_subscriber::SingleSubscriberOutputStream::wait_for_line
never return WaitForLineResult::Timeout. The timeout variant is only produced by the
corresponding *_with_timeout methods.
Variants
Matched
A matching line was observed before the stream ended or the timeout elapsed.
StreamClosed
The stream ended before any matching line was observed.
Timeout
The timeout elapsed before a matching line was observed or the stream ended.