pub struct AutoNameSettings { /* private fields */ }Expand description
Controls in detail which parts of the command are automatically captured as the process name.
Implementations
Sourceimpl AutoNameSettings
impl AutoNameSettings
Sourcepub fn program_only() -> Self
pub fn program_only() -> Self
Capture the program name.
Example: Command::new("ls").arg("-la").env("FOO", "foo) is captured as "ls".
Sourcepub fn program_with_args() -> Self
pub fn program_with_args() -> Self
Capture the program name and all arguments.
Example: Command::new("ls").arg("-la").env("FOO", "foo) is captured as "ls -la".
Sourcepub fn program_with_env_and_args() -> Self
pub fn program_with_env_and_args() -> Self
Capture the program name and all environment variables and arguments.
Example: Command::new("ls").arg("-la").env("FOO", "foo) is captured as "FOO=foo ls -la".