tokio_process_tools

Struct Inspector

pub struct Inspector { /* private fields */ }
An inspector for output lines.

For proper cleanup, call abort() which gracefully waits for the collecting task to complete. It should terminate fast, as an internal termination signal is send to it. If dropped without calling abort(), the termination will be sent as well, but the task will be aborted (forceful, not waiting for completion).

Implementations