pub struct UnixGracefulPhase {
pub signal: UnixGracefulSignal,
pub timeout: Duration,
}Expand description
One step of a Unix graceful-shutdown sequence: a signal to send and a maximum time to wait for the child to exit before escalating.
Fields
signal: UnixGracefulSignalSignal sent at the start of this phase.
timeout: DurationMaximum time to wait for the child to exit after signal is sent. When this elapses the
sequence escalates to the next phase, or to the implicit SIGKILL fallback if this is the
last phase.
Implementations