pub trait OutputStream {
// Required methods
fn read_chunk_size(&self) -> NumBytes;
fn max_buffered_chunks(&self) -> usize;
fn name(&self) -> &'static str;
}Expand description
We support the following implementations:
Required Methods
Sourcefn read_chunk_size(&self) -> NumBytes
fn read_chunk_size(&self) -> NumBytes
The maximum size of every chunk read by the backing stream_reader.
Sourcefn max_buffered_chunks(&self) -> usize
fn max_buffered_chunks(&self) -> usize
The number of chunks held by the underlying async channel.