pub trait OutputStream {
// Required methods
fn chunk_size(&self) -> NumBytes;
fn channel_capacity(&self) -> usize;
fn name(&self) -> &'static str;
}Expand description
We support the following implementations:
Required Methods
Sourcefn chunk_size(&self) -> NumBytes
fn chunk_size(&self) -> NumBytes
The maximum size of every chunk read by the backing stream_reader.
Sourcefn channel_capacity(&self) -> usize
fn channel_capacity(&self) -> usize
The number of chunks held by the underlying async channel.